This demo consists of 100 questions taken from stack overflow, they are listed on the left hand side. Clicking on the headings will display the full question on the right hand side of the page.

Each question contains a heading, a list of tags and the body of the question. All three fields are in the index and you can search using any words you want.

The index is currently being loaded, you can still search but currently not all the data has been indexed.

All